@@ -2,6 +2,7 @@
 package Bubblegum::Object::Array;
 
 use Bubblegum::Class 'with';
+use Bubblegum::Syntax -types;
 
 with 'Bubblegum::Object::Role::Indexed';
 with 'Bubblegum::Object::Role::List';
@@ -14,7 +15,7 @@ use Syntax::Keyword::Junction::None ();
 use Syntax::Keyword::Junction::One  ();
 use Scalar::Util ();
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 
@@ -37,7 +38,7 @@ sub count {
 
 sub defined {
     my $self  = CORE::shift;
-    my $index = bbblgm::chknum CORE::shift;
+    my $index = type_num CORE::shift;
 
     return CORE::defined $self->[$index];
 }
@@ -45,7 +46,7 @@ sub defined {
 
 sub delete {
     my $self  = CORE::shift;
-    my $index = bbblgm::chknum CORE::shift;
+    my $index = type_num CORE::shift;
 
     return CORE::delete $self->[$index];
 }
@@ -53,7 +54,7 @@ sub delete {
 
 sub each {
     my $self = CORE::shift;
-    my $code = bbblgm::chkcode CORE::shift;
+    my $code = type_cref CORE::shift;
 
     my $i=0;
     foreach my $value (@$self) {
@@ -66,7 +67,7 @@ sub each {
 
 sub each_key {
     my $self = CORE::shift;
-    my $code = bbblgm::chkcode CORE::shift;
+    my $code = type_cref CORE::shift;
 
     $code->($_) for (0..$#{$self});
     return $self;
@@ -75,8 +76,8 @@ sub each_key {
 
 sub each_n_values {
     my $self   = CORE::shift;
-    my $number = $_[0] ? bbblgm::chknum  CORE::shift : 2;
-    my $code   = bbblgm::chkcode CORE::shift;
+    my $number = $_[0] ? type_num  CORE::shift : 2;
+    my $code   = type_cref CORE::shift;
     my @values = @$self;
 
     $code->(CORE::splice @values, 0, $number) while @values;
@@ -86,7 +87,7 @@ sub each_n_values {
 
 sub each_value {
     my $self = CORE::shift;
-    my $code = bbblgm::chkcode CORE::shift;
+    my $code = type_cref CORE::shift;
 
     $code->($self->[$_]) for (0..$#{$self});
     return $self;
@@ -103,7 +104,7 @@ sub empty {
 
 sub exists {
     my $self  = CORE::shift;
-    my $index = bbblgm::chknum CORE::shift;
+    my $index = type_num CORE::shift;
     return CORE::exists $self->[$index];
 }
 
@@ -116,14 +117,14 @@ sub first {
 
 sub get {
     my $self  = CORE::shift;
-    my $index = bbblgm::chknum CORE::shift;
+    my $index = type_num CORE::shift;
     return $self->[$index];
 }
 
 
 sub grep {
     my $self = CORE::shift;
-    my $code = bbblgm::chkcode CORE::shift;
+    my $code = type_cref CORE::shift;
     return [CORE::grep { $code->($_) } @$self];
 }
 
@@ -147,7 +148,7 @@ sub iterator {
 
 sub join {
     my $self = CORE::shift;
-    my $separator = bbblgm::chkstr CORE::shift if $_[0];
+    my $separator = type_str CORE::shift if $_[0];
     return CORE::join $separator // '', @$self;
 }
 
@@ -156,7 +157,7 @@ sub keyed {
     my $self = CORE::shift;
     my @keys = @_;
 
-    bbblgm::chkstr $_ for @keys;
+    type_str $_ for @keys;
 
     my $i=0;
     return { CORE::map { $_ => $self->[$i++] } @keys };
@@ -189,7 +190,7 @@ sub list {
 
 sub map {
     my $self = CORE::shift;
-    my $code = bbblgm::chkcode CORE::shift;
+    my $code = type_cref CORE::shift;
     return [CORE::map { $code->($_) } @$self];
 }
 
@@ -314,7 +315,7 @@ sub rsort {
 
 sub set {
     my $self  = CORE::shift;
-    my $index = bbblgm::chknum CORE::shift;
+    my $index = type_num CORE::shift;
     return $self->[$index] = CORE::shift;
 }
 
@@ -334,7 +335,7 @@ sub slice {
     my $self = CORE::shift;
     my @indicies = @_;
 
-    bbblgm::chknum $_ for @indicies;
+    type_num $_ for @indicies;
 
     return [@$self[@indicies]];
 }
@@ -342,7 +343,7 @@ sub slice {
 
 sub sort {
     my $self = CORE::shift;
-    my $code = bbblgm::chkcode CORE::shift if $_[0];
+    my $code = type_cref CORE::shift if $_[0];
     $code ||= sub { $a cmp $b };
     return [CORE::sort { $code->($a, $b) } @$self];
 }
@@ -403,7 +404,7 @@ Bubblegum::Object::Array - Common Methods for Operating on Array References
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
