@@ -2,19 +2,22 @@
 package Bubblegum::Object::String;
 
 use Bubblegum::Class 'with';
+use Bubblegum::Syntax -types;
+
 use Scalar::Util ();
 
 with 'Bubblegum::Object::Role::Defined';
 with 'Bubblegum::Object::Role::Comparison';
+with 'Bubblegum::Object::Role::Coercive';
 with 'Bubblegum::Object::Role::Value';
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 
 sub eq {
     my $self  = CORE::shift;
-    my $other = bbblgm::chkstr CORE::shift;
+    my $other = type_str CORE::shift;
 
     return $self eq $other ? 1 : 0;
 }
@@ -31,7 +34,7 @@ sub eqtv {
 
 sub format {
     my $self   = CORE::shift;
-    my $format = bbblgm::chkstr CORE::shift;
+    my $format = type_str CORE::shift;
 
     return CORE::sprintf $format, $self;
 }
@@ -39,7 +42,7 @@ sub format {
 
 sub gt {
     my $self  = CORE::shift;
-    my $other = bbblgm::chkstr CORE::shift;
+    my $other = type_str CORE::shift;
 
     return $self gt $other ? 1 : 0;
 }
@@ -47,7 +50,7 @@ sub gt {
 
 sub gte {
     my $self  = CORE::shift;
-    my $other = bbblgm::chkstr CORE::shift;
+    my $other = type_str CORE::shift;
 
     return $self ge $other ? 1 : 0;
 }
@@ -55,7 +58,7 @@ sub gte {
 
 sub lt {
     my $self  = CORE::shift;
-    my $other = bbblgm::chkstr CORE::shift;
+    my $other = type_str CORE::shift;
 
     return $self lt $other ? 1 : 0;
 }
@@ -63,7 +66,7 @@ sub lt {
 
 sub lte {
     my $self  = CORE::shift;
-    my $other = bbblgm::chkstr CORE::shift;
+    my $other = type_str CORE::shift;
 
     return $self le $other ? 1 : 0;
 }
@@ -71,7 +74,7 @@ sub lte {
 
 sub ne {
     my $self  = CORE::shift;
-    my $other = bbblgm::chkstr CORE::shift;
+    my $other = type_str CORE::shift;
 
     return $self ne $other ? 1 : 0;
 }
@@ -108,10 +111,10 @@ sub hex {
 
 sub index {
     my ($self, $substr, $pos) = @_;
-    bbblgm::chkstr $substr;
+    type_str $substr;
     return CORE::index $self, $substr if scalar @_ == 2;
 
-    bbblgm::chknum $pos;
+    type_num $pos;
     return CORE::index $self, $substr, $pos
 }
 
@@ -153,10 +156,10 @@ sub reverse {
 
 sub rindex {
     my ($self, $substr, $pos) = @_;
-    bbblgm::chkstr $substr;
+    type_str $substr;
     return CORE::rindex $self, $substr if !defined $pos;
 
-    bbblgm::chknum $pos;
+    type_num $pos;
     return CORE::rindex $self, $substr, $pos;
 }
 
@@ -172,10 +175,10 @@ sub snakecase {
 
 sub split {
     my ($self, $regexp, $limit) = @_;
-    bbblgm::chkre $regexp;
+    type_rref $regexp;
     return [CORE::split /$regexp/, $self] if !defined $limit;
 
-    bbblgm::chknum $limit;
+    type_num $limit;
     return [CORE::split /$regexp/, $self, $limit];
 }
 
@@ -265,7 +268,7 @@ Bubblegum::Object::String - Common Methods for Operating on Strings
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
