@@ -1,17 +1,19 @@
 package Bubblegum::Wrapper::Digest;
 
 use Bubblegum::Class;
+use Bubblegum::Syntax 'raise';
+
 use Digest::MD5 ();
 use Digest::SHA ();
 
 extends 'Bubblegum::Object::Instance';
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 sub BUILD {
     my $self = shift;
 
-    $self->data->typeof('str') or bbblgm::croak
+    $self->data->typeof('str') or raise
         CORE::sprintf q(Wrapper package "%s" requires string data), ref $self;
 }
 
